@@ -1,3 +1,7 @@
+
+import os
+
+
 def add(a, b):
     return a + b
 
@@ -11,4 +15,8 @@ def divide(a, b):
     return a / b
 
 def exp(a, b):
-    return a**b
\ No newline at end of file
+    return a**b
+
+def display_path():
+    directory = os.getcwd()
+    print(directory)
\ No newline at end of file
